==> vtk-8.1.1-1-x86_64.pkg.tar.xz: vtk/vtkSTLWriter.java <==
// java wrapper for vtkSTLWriter object
//

package vtk;
import vtk.*;

public class vtkSTLWriter extends vtkWriter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetInput_2();
  public vtkPolyData GetInput() {
    long temp = GetInput_2();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_3(int id0);
  public vtkPolyData GetInput(int id0) {
    long temp = GetInput_3(id0);

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFileName_4(String id0);
  public void SetFileName(String id0)
    { SetFileName_4(id0); }

  private native String GetFileName_5();
  public String GetFileName()
    { return GetFileName_5(); }

  private native void SetHeader_6(String id0);
  public void SetHeader(String id0)
    { SetHeader_6(id0); }

  private native String GetHeader_7();
  public String GetHeader()
    { return GetHeader_7(); }

  private native void SetFileType_8(int id0);
  public void SetFileType(int id0)
    { SetFileType_8(id0); }

  private native int GetFileTypeMinValue_9();
  public int GetFileTypeMinValue()
    { return GetFileTypeMinValue_9(); }

  private native int GetFileTypeMaxValue_10();
  public int GetFileTypeMaxValue()
    { return GetFileTypeMaxValue_10(); }

  private native int GetFileType_11();
  public int GetFileType()
    { return GetFileType_11(); }

  private native void SetFileTypeToASCII_12();
  public void SetFileTypeToASCII()
    { SetFileTypeToASCII_12(); }

  private native void SetFileTypeToBinary_13();
  public void SetFileTypeToBinary()
    { SetFileTypeToBinary_13(); }

  public vtkSTLWriter() { super(); }

  public vtkSTLWriter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-7-x86_64.pkg.tar.xz: vtk/vtkSTLWriter.java <==
// java wrapper for vtkSTLWriter object
//

package vtk;
import vtk.*;

public class vtkSTLWriter extends vtkWriter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetInput_2();
  public vtkPolyData GetInput() {
    long temp = GetInput_2();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_3(int id0);
  public vtkPolyData GetInput(int id0) {
    long temp = GetInput_3(id0);

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFileName_4(String id0);
  public void SetFileName(String id0)
    { SetFileName_4(id0); }

  private native String GetFileName_5();
  public String GetFileName()
    { return GetFileName_5(); }

  private native void SetHeader_6(String id0);
  public void SetHeader(String id0)
    { SetHeader_6(id0); }

  private native String GetHeader_7();
  public String GetHeader()
    { return GetHeader_7(); }

  private native void SetBinaryHeader_8(vtkUnsignedCharArray id0);
  public void SetBinaryHeader(vtkUnsignedCharArray id0)
    { SetBinaryHeader_8(id0); }

  private native long GetBinaryHeader_9();
  public vtkUnsignedCharArray GetBinaryHeader() {
    long temp = GetBinaryHeader_9();

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFileType_10(int id0);
  public void SetFileType(int id0)
    { SetFileType_10(id0); }

  private native int GetFileTypeMinValue_11();
  public int GetFileTypeMinValue()
    { return GetFileTypeMinValue_11(); }

  private native int GetFileTypeMaxValue_12();
  public int GetFileTypeMaxValue()
    { return GetFileTypeMaxValue_12(); }

  private native int GetFileType_13();
  public int GetFileType()
    { return GetFileType_13(); }

  private native void SetFileTypeToASCII_14();
  public void SetFileTypeToASCII()
    { SetFileTypeToASCII_14(); }

  private native void SetFileTypeToBinary_15();
  public void SetFileTypeToBinary()
    { SetFileTypeToBinary_15(); }

  public vtkSTLWriter() { super(); }

  public vtkSTLWriter(long id) { super(id); }
  public native long   VTKInit();

}
